--[[
An ActionButton that has a defined behavior of "do nothing".  Normally, this
shows up as a typical cancel button (x), but can show up as a menu selection
with the word "Cancel" associated with it.  Other looks are also possible.

There is one ActionButtonNone per UnitGroupHeader.
Each ActionButtonNone instance is associated with a single UnitGroupHeader.
--]]
uab.classes.ActionButtonNone = uab.mixins.aceOO.Class()

function uab.classes.ActionButtonNone.ShowTooltip(frame)
    if uab.db.profile.tooltips then
        GameTooltip:SetOwner(frame, "ANCHOR_RIGHT")
        GameTooltip:SetBackdropColor(0.1, 0.1, 0.1, 0.8)
        GameTooltip:SetText("Cancel unit action", nil, nil, nil, nil, true)
    end
end

function uab.classes.ActionButtonNone.prototype:init(header, minshowstate, maxshowstate)
	uab.classes.ActionButtonNone.super.prototype.init(self)
	
	self.header = header
    self.enabled = true
    self.minshowstate = minshowstate
    self.maxshowstate = maxshowstate
    self.showstates = {}
	
	--[[
	Create frame
	--]]
    self.frame = CreateFrame(
        "Button",
        self.header.frame:GetName().."ActionBtnNone",
        self.header.frame,
        "UAB_StandardCancelButtonTemplate")
    self.frame.uabobj = self
    self.frame:Show()

    self.frame:SetAttribute("useparent-unit", "true")
    self.frame:SetAttribute("useparent-unitsuffix", "true")
    self.frame:SetAttribute("state", "0")

    self.header.frame:SetAttribute("addchild", self.frame)
    
    self.frame:SetPoint("CENTER", 0, 0)
    self.frame:SetScript("OnEnter", function(self, motion) uab.classes.ActionButtonNone.ShowTooltip(self) end)
    self.frame:SetScript("OnShow", function(self)
        self.uabobj:OnShow()
    end)
    self.frame:SetScript("OnLeave", function(self, motion) GameTooltip:Hide() end)
    
    self.frame:Hide()
end

function uab.classes.ActionButtonNone.prototype:SetScale(scale)
    self.frame:SetScale(scale)
end

function uab.classes.ActionButtonNone.prototype:AddActiveStateUnit(state, unit)
	-- need to set the statebutton attributes on the button, to associate
	-- a click when in "state" to apply to "unit".
	-- This is not needed in WoW 2.0.1, since we don't use statebutton 
	-- attributes to associate clicks to units.

	-- Add the specified state as a "visible" state, so that when the control 
	-- for that state indicates a "show" condition, we will show the frame.
	self.showstates[state] = unit

	if self.enabled then
		self:Enable()
	else
		self:Disable()
	end
end

function uab.classes.ActionButtonNone.prototype:Show()
	-- Nothing to do here, since this is the cancel button, which does not
	-- change visual appearance.
end

function uab.classes.ActionButtonNone.prototype:Hide()
	self.frame:Hide()
end

function uab.classes.ActionButtonNone.prototype:Enable()
    self.frame:SetAttribute("showstates", self.minshowstate.."-"..self.maxshowstate)
    self.frame:SetAttribute("hidestates", nil)

--[[
    -- in WoW 2.0.2, we will have to go through all the "show" states, and
	-- add each to our "showstate" attribute.  For now, set the "hidestate"
	-- attribute to include 0 and 1
	local attr
	
	for state, unit in pairs(self.showstates) do
		if attr then
			attr = attr .. ","
		else
            attr = ""
        end
		
        attr = attr .. state
	end
	
	self.frame:SetAttribute("showstates", attr)
	self.frame:SetAttribute("hidestates", nil)
--]]
    
    self.frame:SetAttribute("newstate", "*:0")
	self.enabled = true
end

function uab.classes.ActionButtonNone.prototype:Disable()
    self.frame:SetAttribute("showstates", nil)
    self.frame:SetAttribute("hidestates", "*")

--[[    
	-- make all the showstates hidestates, and include 0 in the hidestates.
	local attr = "0"
	
	for state, unit in pairs(self.showstates) do
		if attr then
			attr = attr .. ","
		else
            attr = ""
        end
		
		attr = attr .. state
	end

	self.frame:SetAttribute("hidestates", attr)
	self.frame:SetAttribute("showstates", nil)
--]]
    
    self.frame:SetAttribute("newstate", "*:0")
	self.enabled = nil
end

function uab.classes.ActionButtonNone.prototype:Frame()
	return self.frame
end

function uab.classes.ActionButtonNone.prototype:OnShow()
    self.frame:SetFrameStrata("FULLSCREEN_DIALOG")
end

